QueryDecodable<T> class abstract

(Optional) Interface for objects that know how to decode themselves from a map of query parameters. This can be used in more advanced scenarios.

Classes that implement this interface should provide a fromQuery method that returns a new instance of the class from the provided map.

Constructors

QueryDecodable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromQuery(Map<String, dynamic> map) → T
Returns a new instance of T from the provided map of query parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited