QueryParamsDecoder class

Decodes a query string (e.g. "?foo=bar&num=42&...") into a Map<String, dynamic>. This class extends the Converter class to provide a custom implementation for decoding query strings into a map.

Inheritance

Constructors

QueryParamsDecoder()
Creates a constant QueryParamsDecoder instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<String> stream) Stream<Map<String, dynamic>>
Transforms the provided stream.
inherited
cast<RS, RT>() Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String input) Map<String, dynamic>
Converts the input query string into a Map<String, dynamic>.
override
fuse<TT>(Converter<Map<String, dynamic>, TT> other) Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Map<String, dynamic>> sink) Sink<String>
Starts a chunked conversion.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited