console library

Classes

CliLogger
Minimal logger for CLI output.
CliVersion
Routed CLI core utilities.
DevOptions
Options used by the dev command to run a development server.
ProviderArtisanalCommandRegistration
ProviderArtisanalCommandRegistry
Registry for provider-registered artisanal command factories.
ProviderCommandRegistration
ProviderCommandRegistry
Registry for provider-registered args-based commands.

Functions

formatRoutesTable(Iterable<String> routes) String
Formats a simple routes list for use in list command outputs.
registerProviderArtisanalCommands(CommandRunner<void> runner, Iterable<ProviderArtisanalCommandRegistration> registrations, String usage) → void
Registers provider artisanal commands with the given runner.
registerProviderCommands(CommandRunner<void> runner, Iterable<ProviderCommandRegistration> registrations, String usage) → void
Registers provider commands with the given runner.
runDevServer(DevOptions options, {CliLogger? logger}) Future<Process>
Runs a development server for a Routed app.
spawnDartProcess(List<String> args, {Map<String, String>? environment, String? workingDirectory, bool inheritStdio = true}) Future<Process>
Spawns a Dart process using the current Dart executable.
usageHeader() String
Short usage header for help text.