plugin top-level property
RoutedAnalyzerPlugin
plugin
final
The analyzer plugin instance discovered by the analysis server.
Implementation
final plugin = RoutedAnalyzerPlugin();
The analyzer plugin instance discovered by the analysis server.
final plugin = RoutedAnalyzerPlugin();