schema property
Optional API schema metadata for this route.
Contains request body, parameter, and response metadata used for OpenAPI generation and runtime validation.
Implementation
final RouteSchema? schema;
Optional API schema metadata for this route.
Contains request body, parameter, and response metadata used for OpenAPI generation and runtime validation.
final RouteSchema? schema;