PolicyAction enum
Policy-based authorization built on top of Haigate.
Policies encapsulate authorization decisions for a specific resource type
(e.g. ProjectPolicy). Use PolicyBinding with an ability prefix to
register Haigate abilities like project.view or project.update.
Available policy actions.
Values
- view → const PolicyAction
- create → const PolicyAction
- update → const PolicyAction
- delete → const PolicyAction
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PolicyAction> - A constant List of the values in this enum, in order of their declaration.