WebAuthnAuthenticatorSelection class

Authenticator selection criteria for registration.

Constructors

WebAuthnAuthenticatorSelection({String? authenticatorAttachment, String residentKey = 'preferred', String userVerification = 'preferred'})
const

Properties

authenticatorAttachment String?
Attachment type (platform, cross-platform).
final
hashCode int
The hash code for this object.
no setterinherited
residentKey String
Resident key requirement (required, preferred, discouraged).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userVerification String
User verification requirement.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited