WebAuthnRegistrationOptions class

Options for WebAuthn registration ceremonies.

Constructors

WebAuthnRegistrationOptions({String attestation = 'none', WebAuthnAuthenticatorSelection? authenticatorSelection, bool excludeCredentials = true})
const

Properties

attestation String
Attestation conveyance preference (none, indirect, direct).
final
authenticatorSelection WebAuthnAuthenticatorSelection?
Authenticator selection criteria.
final
excludeCredentials bool
Whether to exclude existing credentials during registration.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited