QueryEncodable class abstract
Interface for objects that know how to encode themselves to query parameters.
Classes that implement this interface should provide a toQuery method
that returns a map representation suitable for query encoding.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toQuery(
) → Map< String, dynamic> -
Returns a
Map<String, dynamic>representation suitable for query encoding. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited