QueryParamsCodec class
A codec that encodes and decodes query strings with special handling for objects that implement QueryEncodable.
This class extends the Codec class to provide custom implementations for encoding and decoding query strings.
Constructors
- QueryParamsCodec()
-
Creates a constant QueryParamsCodec instance.
const
Properties
- decoder → QueryParamsDecoder
-
Returns an instance of QueryParamsDecoder for decoding query strings.
no setteroverride
- encoder → QueryParamsEncoder
-
Returns an instance of QueryParamsEncoder for encoding query strings.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
String, Map< String, dynamic> > -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String encoded) → Map< String, dynamic> -
Decodes
encodeddata.inherited -
encode(
Map< String, dynamic> input) → String -
Encodes
input.inherited -
fuse<
R> (Codec< String, R> other) → Codec<Map< String, dynamic> , R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited