QueryParamsEncoder class
Encodes a Map<String, dynamic> into a query string, but first
recursively converts objects that implement QueryEncodable via toQuery().
This class extends the Converter class to provide a custom implementation for encoding maps into query strings.
Constructors
- QueryParamsEncoder()
-
Creates a constant QueryParamsEncoder instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< Map< stream) → Stream<String, dynamic> >String> -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
Map< String, dynamic> input) → String -
Converts the input map into a query string.
override
-
fuse<
TT> (Converter< String, TT> other) → Converter<Map< String, dynamic> , TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink< String> sink) → Sink<Map< String, dynamic> > -
Starts a chunked conversion.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited