InMemoryAuthAdapter class
In-memory adapter for testing and prototypes.
- Inheritance
-
- Object
- AuthAdapter
- InMemoryAuthAdapter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createSession(
AuthSession session) → Future< AuthSession> -
Persists a server-side session.
override
-
createUser(
AuthUser user) → Future< AuthUser> -
Persists a new user.
override
-
deleteSession(
String sessionToken) → Future< void> -
Deletes a session by token.
override
-
deleteVerificationTokens(
String identifier) → Future< void> -
Deletes verification tokens for an identifier.
override
-
getAccount(
String providerId, String providerAccountId) → Future< AuthAccount?> -
Loads a provider account link.
override
-
getSession(
String sessionToken) → Future< AuthSession?> -
Loads a session for server-side sessions.
override
-
getUserByEmail(
String email) → Future< AuthUser?> -
Looks up a user by email address.
override
-
getUserById(
String id) → Future< AuthUser?> -
Looks up a user by identifier.
override
-
linkAccount(
AuthAccount account) → Future< void> -
Links a provider account to a user.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerCredentials(
AuthCredentials credentials) → Future< AuthUser?> -
Registers a new user from credential input.
override
-
saveVerificationToken(
AuthVerificationToken token) → Future< void> -
Saves an email verification token.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateUser(
AuthUser user) → Future< AuthUser?> -
Updates a user record.
override
-
useVerificationToken(
String identifier, String token) → Future< AuthVerificationToken?> -
Consumes an email verification token.
override
-
verifyCredentials(
AuthCredentials credentials) → Future< AuthUser?> -
Verifies credential sign-in against your datastore.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited