UnhandledSignalError class final
Emitted when a signal handler fails.
Constructors
- UnhandledSignalError({required String name, required Event event, required Object error, required StackTrace stack, Object? key, Object? sender})
Properties
- error → Object
-
final
- event → Event
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Object?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → Object?
-
final
- stack → StackTrace
-
final
- timestamp → DateTime
-
The timestamp when the event was created.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited